#!/bin/bash

echostep() {
    str="$1"
    len=${#str}
    pad="$(printf %-$((len + 5))s '')"
    pre="$(tput bold)$(tput setaf 4)$(tput rev)"
    post="$(tput sgr0)"
    echo ""
    echo "----"
    echo "$pre$pad$post"
    echo "$pre>> $1  $post"
    echo "$pre$pad$post"
    echo "----"
}

clear

cd ~/Desktop/myfiles
mkdir -p Programmation
cd Programmation
mkdir -p .vscode

# Install necessary extensions
echostep "Installing necessary extensions..."
code --install-extension ms-vscode.cpptools
code --install-extension formulahendry.code-runner

# Configure launch.json
echostep "Configuring launch preference..."
rm -f .vscode/launch.json
cat > .vscode/launch.json << EOM
{
	"version": "0.2.0",
	"configurations": [{
		"name": "(gdb) Launch",
		"type": "cppdbg",
		"request": "launch",
		"program": "\${fileDirname}/\${fileBasenameNoExtension}",
		"args": [],
		"stopAtEntry": false,
		"cwd": "\${fileDirname}",
		"environment": [],
		"externalConsole": false,
		"internalConsoleOptions": "neverOpen",
		"MIMode": "gdb",
		"miDebuggerPath": "gdb",
		"setupCommands": [{
			"description": "Enable pretty-printing for gdb",
			"text": "-enable-pretty-printing",
			"ignoreFailures": false
		}],
		"preLaunchTask": "Build"
	}]
}
EOM

# Configure tasks.json
echostep "Configuring task preference..."
rm -f .vscode/tasks.json
cat > .vscode/tasks.json << EOM
{
	"version": "2.0.0",
	"tasks": [{
  	"label": "Build",
  	"command": "g++",
  	"args": [
  		"\${file}",
  		"-o",
  		"\${fileDirname}/\${fileBasenameNoExtension}",
  		"-g",
  		"-m64",
  		"-Wall",
  		"-static-libgcc",
  		"-std=c++11"
  	],
  	"type": "shell",
  	"group": {
  		"kind": "build",
  		"isDefault": true
  	},
  	"presentation": {
  		"echo": true,
  		"reveal": "always",
  		"focus": false,
  		"panel": "new"
  	},
  	"problemMatcher":"\$gcc"
  }]
}
EOM

# Configure settings.json
echostep "Configuring setting preference..."
rm -f .vscode/settings.json
cat > .vscode/settings.json << EOM
{
	"files.defaultLanguage": "cc",
	"editor.formatOnType": true,
	"editor.suggest.snippetsPreventQuickSuggestions": false,
	"code-runner.runInTerminal": true,
	"code-runner.executorMap": {
		"cpp": "g++ \$fileName -o \$fileNameWithoutExt -Wall -m64 -static-libgcc -std=c++11 && \$dir\$fileNameWithoutExt"
	},
	"code-runner.saveFileBeforeRun": true,
	"code-runner.preserveFocus": false,
	"code-runner.clearPreviousOutput": true,
	"code-runner.ignoreSelection": true,
	"code-runner.fileDirectoryAsCwd": true
}
EOM

# A simple test
mkdir -p Test
if [ ! -f Test/test.cc ];
then
cat > Test/test.cc << EOM
#include <iostream>

void my_swap( int& a, int& b );

int main()
{
	int a( 4 );
	int b( 1 );
	b += 1;
	a += b;
	my_swap( a, b );
	std::cout << "a = " << a << ", b = " << b << "\n";
	return 0;
}

void my_swap( int& a, int& b )
{
	a = a + b;
	b = a - b;
	a = a - b;
}
EOM
fi

echostep "Set up accomplished!"
